SharedMemoryObject

Trait SharedMemoryObject 

pub trait SharedMemoryObject:
    MemoryMappingOps
    + Send
    + Sync {
    // Required methods
    fn size(&self) -> usize;
    fn resize(&self, new_size: usize) -> Result<(), &'static str>;
    fn id(&self) -> String;
    fn is_valid(&self) -> bool;
}
Shared memory operations

This trait extends the base functionality for shared memory objects.

Required Methods

fn size(&self) -> usize

Get the size of the shared memory region in bytes

fn resize(&self, new_size: usize) -> Result<(), &'static str>

Resize the shared memory region (within capacity)

fn id(&self) -> String

Get a unique identifier for this shared memory object

fn is_valid(&self) -> bool

Check if the shared memory is still valid

Implementors